@@ -6,16 +6,16 @@
 #include "ripperpluginloader.h"
 #include "combobutton.h"
 
-#include <klistview.h>
-#include <klocale.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <knuminput.h>
 #include <ktextedit.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 
 #include <tqlayout.h>
 #include <tqlabel.h>
@@ -35,11 +35,11 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     config = _config;
 
     // create an icon loader object for loading icons
-    KIconLoader* iconLoader = new KIconLoader();
+    TDEIconLoader* iconLoader = new TDEIconLoader();
 
     // let the dialog look nice
     setCaption( i18n("Add CD tracks") );
-    setIcon( iconLoader->loadIcon("cdaudio_unmount",KIcon::Small) );
+    setIcon( iconLoader->loadIcon("media-optical-cdaudio",TDEIcon::Small) );
 
     // the grid for all widgets in the dialog
     TQGridLayout* gridLayout = new TQGridLayout( this, 1, 1, 11, 6, "gridLayout" );
@@ -76,7 +76,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
              );
     //artistBox->addStretch();
     artistBox->addSpacing( 130 );
-//     pCDDB = new KPushButton( iconLoader->loadIcon("cdaudio_unmount",KIcon::Small), i18n("Request CDDB"), this, "pCDDB" );
+//     pCDDB = new KPushButton( iconLoader->loadIcon("media-optical-cdaudio",TDEIcon::Small), i18n("Request CDDB"), this, "pCDDB" );
 //     topGridLayout->addWidget( pCDDB, 0, 8 );
 
     // set up the second row at the top
@@ -102,13 +102,13 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     cGenre = new KComboBox( true, this, "cGenre" );
     cGenre->insertStringList( tagEngine->genreList );
     cGenre->setCurrentText( "" );
-    KCompletion* cGenreCompletion = cGenre->completionObject();
+    TDECompletion* cGenreCompletion = cGenre->completionObject();
     cGenreCompletion->insertItems( tagEngine->genreList );
     cGenreCompletion->setIgnoreCase( true );
     albumBox->addWidget( cGenre );
 
     // generate the list view for the tracks
-    trackList = new KListView( this, "trackList" );
+    trackList = new TDEListView( this, "trackList" );
     gridLayout->addWidget( trackList, 1, 0 );
     // and fill in the headers
     trackList->addColumn( i18n("Track") );
@@ -137,14 +137,14 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
 
     // add the up and down buttons
     pTrackUp = new KPushButton( " ", tagGroupBox, "pTrackUp" );
-    pTrackUp->setPixmap( iconLoader->loadIcon("up",KIcon::Toolbar) );
+    pTrackUp->setPixmap( iconLoader->loadIcon("go-up",TDEIcon::Toolbar) );
     pTrackUp->setAutoRepeat( true );
     connect( pTrackUp, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(trackUpPressed())
              );
     tagGridLayout->addWidget( pTrackUp, 0, 0 );
     pTrackDown = new KPushButton( " ", tagGroupBox, "pTrackDown" );
-    pTrackDown->setPixmap( iconLoader->loadIcon("down",KIcon::Toolbar) );
+    pTrackDown->setPixmap( iconLoader->loadIcon("go-down",TDEIcon::Toolbar) );
     pTrackDown->setAutoRepeat( true );
     connect( pTrackDown, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(trackDownPressed())
@@ -164,7 +164,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
                this, TQT_SLOT(trackTitleChanged(const TQString&))
              );
     pTrackTitleEdit = new KPushButton( " ", tagGroupBox, "pTrackTitleEdit" );
-    pTrackTitleEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pTrackTitleEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pTrackTitleEdit->setFixedSize( lTrackTitle->sizeHint().height(), lTrackTitle->sizeHint().height() );
     pTrackTitleEdit->hide();
     trackTitleBox->addWidget( pTrackTitleEdit );
@@ -183,7 +183,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
                this, TQT_SLOT(trackArtistChanged(const TQString&))
              );
     pTrackArtistEdit = new KPushButton( " ", tagGroupBox, "pTrackArtistEdit" );
-    pTrackArtistEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pTrackArtistEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pTrackArtistEdit->setFixedSize( lTrackArtist->sizeHint().height(), lTrackArtist->sizeHint().height() );
     pTrackArtistEdit->hide();
     trackArtistBox->addWidget( pTrackArtistEdit );
@@ -198,7 +198,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
                this, TQT_SLOT(trackComposerChanged(const TQString&))
              );
     pTrackComposerEdit = new KPushButton( " ", tagGroupBox, "pTrackComposerEdit" );
-    pTrackComposerEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pTrackComposerEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pTrackComposerEdit->setFixedSize( lTrackComposer->sizeHint().height(), lTrackComposer->sizeHint().height() );
     pTrackComposerEdit->hide();
     trackArtistBox->addWidget( pTrackComposerEdit );
@@ -218,7 +218,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
                this, TQT_SLOT(trackCommentChanged())
              );
     pTrackCommentEdit = new KPushButton( " ", tagGroupBox, "pTrackCommentEdit" );
-    pTrackCommentEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pTrackCommentEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pTrackCommentEdit->setFixedSize( lTrackTitle->sizeHint().height(), lTrackTitle->sizeHint().height() );
     pTrackCommentEdit->hide();
     trackCommentBox->addWidget( pTrackCommentEdit );
@@ -239,7 +239,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     gridLayout->addLayout( controlBox, 4, 0 );
 
     // add the control elements
-    pSaveCue = new KPushButton( iconLoader->loadIcon("filesave",KIcon::Small), i18n("Save cuesheet ..."), this, "pSaveCue" );
+    pSaveCue = new KPushButton( iconLoader->loadIcon("document-save",TDEIcon::Small), i18n("Save cuesheet ..."), this, "pSaveCue" );
     controlBox->addWidget( pSaveCue );
     connect( pSaveCue, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(saveCuesheetClicked())
@@ -247,16 +247,16 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
     controlBox->addStretch();
 
     cAdd = new ComboButton( this, "cAdd" );
-    cAdd->insertItem( iconLoader->loadIcon("fileopen",KIcon::Small),i18n("Add all tracks") );
-    cAdd->insertItem( iconLoader->loadIcon("fileopen",KIcon::Small),i18n("Add selected tracks") );
+    cAdd->insertItem( iconLoader->loadIcon("document-open",TDEIcon::Small),i18n("Add all tracks") );
+    cAdd->insertItem( iconLoader->loadIcon("document-open",TDEIcon::Small),i18n("Add selected tracks") );
     RipperPlugin* plugin = config->getCurrentRipper();
-    if( plugin != 0 && plugin->rip.full_disc.enabled ) cAdd->insertItem( iconLoader->loadIcon("cdaudio_unmount",KIcon::Small),i18n("Add full CD as one file") );
+    if( plugin != 0 && plugin->rip.full_disc.enabled ) cAdd->insertItem( iconLoader->loadIcon("media-optical-cdaudio",TDEIcon::Small),i18n("Add full CD as one file") );
     //cAdd->setSizeMode( ComboButton::Min );
     controlBox->addWidget( cAdd );
     connect( cAdd, TQT_SIGNAL(clicked(int)),
                this, TQT_SLOT(addClicked(int))
              );
-    pCancel = new KPushButton( iconLoader->loadIcon("cancel",KIcon::Small), i18n("Cancel"), this, "pCancel" );
+    pCancel = new KPushButton( iconLoader->loadIcon("cancel",TDEIcon::Small), i18n("Cancel"), this, "pCancel" );
     controlBox->addWidget( pCancel );
     connect( pCancel, TQT_SIGNAL(clicked()),
                this, TQT_SLOT(reject())
@@ -291,7 +291,7 @@ CDOpener::CDOpener( Config* _config, CDManager* _cdManager, TagEngine* _tagEngin
         if( year == 0 ) year = (*it)->year;
         if( genre == "" ) genre = (*it)->genre;
 
-        new KListViewItem( trackList, TQString().sprintf("%02i",(*it)->track), (*it)->artist, (*it)->composer, (*it)->title, TQString().sprintf("%i:%02i",(*it)->length/60,(*it)->length%60) );
+        new TDEListViewItem( trackList, TQString().sprintf("%02i",(*it)->track), (*it)->artist, (*it)->composer, (*it)->title, TQString().sprintf("%i:%02i",(*it)->length/60,(*it)->length%60) );
     }
     trackList->setSorting( -1 );
 
